@@ -84,7 +84,7 @@ class BaseAdaptorField(object):
         return 'inplaceedit %sinplaceedit' % (self.name)
 
     @classmethod
-    def get_config(self, **kwargs):
+    def get_config(self, request, **kwargs):
         """
         Get the arguments given to the template tag element and complete these
         with the ones from the settings.py if necessary.
@@ -101,7 +101,6 @@ class BaseAdaptorField(object):
         else:
             # Solution 2: Updating the configured config with the default one.
             config = dict(config_from_settings, **config)
-
         return config
 
     def get_form_class(self):
@@ -373,6 +372,12 @@ class BaseDateField(BaseAdaptorField):
         return super(BaseDateField, self).render_media_field(template_name,
                                                              extra_context=context)
 
+    def render_value(self, field_name=None):
+        val = super(BaseDateField, self).render_value(field_name)
+        if not isinstance(val, string):
+            val = apply_filters(val, [self.filter_render_value])
+        return val
+
 
 class AdaptorDateField(BaseDateField):
 
@@ -380,6 +385,10 @@ class AdaptorDateField(BaseDateField):
     def name(self):
         return 'date'
 
+    def __init__(self, *args, **kwargs):
+        super(AdaptorDateField, self).__init__(*args, **kwargs)
+        self.filter_render_value = "date:'%s'" % settings.DATE_FORMAT
+
     def render_field(self, template_name="inplaceeditform/adaptor_date/render_field.html", extra_context=None):
         return super(AdaptorDateField, self).render_field(template_name, extra_context=extra_context)
 
@@ -388,12 +397,6 @@ class AdaptorDateField(BaseDateField):
         field.field.widget = AdminDateWidget()
         return field
 
-    def render_value(self, field_name=None):
-        val = super(AdaptorDateField, self).render_value(field_name)
-        if not isinstance(val, string):
-            val = apply_filters(val, ["date:'%s'" % settings.DATE_FORMAT])
-        return val
-
 
 class AdaptorDateTimeField(BaseDateField):
 
@@ -401,6 +404,10 @@ class AdaptorDateTimeField(BaseDateField):
     def name(self):
         return 'datetime'
 
+    def __init__(self, *args, **kwargs):
+        super(AdaptorDateTimeField, self).__init__(*args, **kwargs)
+        self.filter_render_value = "date:'%s'" % settings.DATETIME_FORMAT
+
     def render_field(self, template_name="inplaceeditform/adaptor_datetime/render_field.html", extra_context=None):
         return super(AdaptorDateTimeField, self).render_field(template_name, extra_context=extra_context)
 
@@ -412,12 +419,6 @@ class AdaptorDateTimeField(BaseDateField):
         field.field.widget = AdminSplitDateTime()
         return field
 
-    def render_value(self, field_name=None):
-        val = super(AdaptorDateTimeField, self).render_value(field_name)
-        if not isinstance(val, string):
-            val = apply_filters(val, ["date:'%s'" % settings.DATETIME_FORMAT])
-        return val
-
 
 class AdaptorTimeField(BaseDateField):
 
@@ -425,17 +426,15 @@ class AdaptorTimeField(BaseDateField):
     def name(self):
         return 'time'
 
+    def __init__(self, *args, **kwargs):
+        super(AdaptorTimeField, self).__init__(*args, **kwargs)
+        self.filter_render_value = "date:'%s'" % settings.TIME_FORMAT
+
     def get_field(self):
         field = super(AdaptorTimeField, self).get_field()
         field.field.widget = AdminTimeWidget()
         return field
 
-    def render_value(self, field_name=None):
-        val = super(AdaptorTimeField, self).render_value(field_name)
-        if not isinstance(val, string):
-            val = apply_filters(val, ["date:'%s'" % settings.TIME_FORMAT])
-        return val
-
 
 class AdaptorIntegerField(BaseAdaptorField):
 
